# lab2_group_analysis.R
# PSYCH 4165 Lab 2
# Command file for using lme() to compute a
# repeated measures analysis of variance in R.
# Lew Harvey
# 1 February 2010

library(nlme)		# load the nlme library to use lme()

# Read in group data in wide format from Excel text file:
fn <- file("lab2_group_data_wide.txt")
df.wide <- read.delim(fn, header=TRUE)


# ******************************************************
# reshape the file into long format
# Note: reshape() is a bit of a pain to use but what it does
# is take data that are in a so-called wide format
# (one row per subject, separate columns per dependent variable)
# and put it into the long formate needed by many R analysis routines
# (multiple rows per subject, single column per dependent variable)
df.long <- reshape(df.wide,
	varying = list(c("da_no_eyes", "da_with_eyes"), c("htm_no_eyes", "htm_with_eyes"), c("sdt_AIC", "htm_AIC")),
	v.names = c("da", "htm_p", "aic"),
	timevar = c("eyes", "mod"),
	idvar = "subj",
	times = c("noEyes", "withEyes"),
	direction = "long")
	
rownames(df.long) <- 1:dim(df.long)[1]
df.long[df.long$mod == "noEyes", "mod"] <- "sdt"
df.long[df.long$mod == "withEyes", "mod"] <- "htm"
df.long$eyes <- factor(df.long$eyes)
df.long$mod <- factor(df.long$mod)
df <- df.long
# ******************************************************
# make functions to draw strip and box plots
# plot1()  plots AIC fit against the two models
# plot2()  plots memory sensitivity for eyes/no eyes
# ******************************************************

# Write out a summary of the variables in the data frame:
print(summary(df))

# Test the hypothesis that SDT and HTM are
# equally good at describing the data
plot1 <- function() {
	par(mfcol=c(2,1))	# two plots per figure
	# Make a strip chart of the data
	with(df,  stripchart(aic ~  mod,
		method = "jitter",  jitter = 0.03,
		xlab = "Goodness-of-Fit (AIC)",
		ylab = "Detection Model",
		main = "Lab 2 Group Data"))
	
	# Make a box plot of the data:
	boxplot(aic ~ mod, data = df, horizontal = TRUE,
		ylab = "Detection Model",
		xlab = "Badness-of-Fit (AIC)")
	par(mfcol=c(1,1))
}	
# Compute a repeated measures ANOVA
print("Goodness-of-Fit ANOVA and Means")
a <- lme(aic ~ mod, random = ~ 1 | subj, data = df)
print(anova(a))
with(df,print(cbind(mean = tapply(aic, mod, mean),
	std.dev = tapply(aic, mod, sd),
	n = tapply(aic, mod, length))))	


# Test the hypothesis that eyes have no influence on face memory
plot2 <- function() {
	par(mfcol=c(2,1))	# two plots per figure
	# Make a strip chart of the data
	with(df, stripchart(da ~ eyes, method = "jitter", jitter = 0.03,
		xlab = "Sensitivity (Da)",
		ylab = "Eyes (Yes or No)",
		main = "Lab 2 Group Data"))
	
	# Make a box plot of the data
	boxplot(da ~ eyes, data = df, horizontal = TRUE,
		ylab = "Eyes (Yes or No)",
		xlab = "Sensitivity (Da)")
	par(mfcol=c(1,1))	# two plots per figure
}	
# Compute the repeated measures ANOVA
print("d-sub-a ANOVA and Means")
b <- lme(da ~ eyes, random = ~ 1 | subj, data = df)
print(anova(b))
with(df,print(cbind(mean = tapply(da, eyes, mean),
	std.dev = tapply(da, eyes, sd),
	n = tapply(da, eyes, length))))

